@@ -18,8 +18,8 @@ package Pod::Loom;
 #---------------------------------------------------------------------
 
 use 5.008;
-our $VERSION = '0.05';
-# This file is part of Pod-Loom 0.05 (October 15, 2011)
+our $VERSION = '0.06';
+# This file is part of Pod-Loom 0.06 (January 12, 2013)
 
 use Moose 0.65; # attr fulfills requires
 use Carp qw(croak);
@@ -113,6 +113,8 @@ sub weave
   my $docstr = $ppi->serialize;
   $docstr =~ s/\n*\z/\n/;       # ensure it ends with one LF
 
+  return $newPod if $docstr eq "\n" and not defined $end; # Pure POD file
+
   return defined $end
       ? "$docstr\n$newPod\n$end"
       : "$docstr\n__END__\n\n$newPod";
@@ -142,9 +144,9 @@ Pod::Loom - Weave pseudo-POD into real POD
 
 =head1 VERSION
 
-This document describes version 0.05 of
-Pod::Loom, released October 15, 2011
-as part of Pod-Loom version 0.05.
+This document describes version 0.06 of
+Pod::Loom, released January 12, 2013
+as part of Pod-Loom version 0.06.
 
 =head1 WARNING
 
@@ -289,7 +291,7 @@ L<< http://github.com/madsen/pod-loom >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2013 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
